@@ -9,6 +9,6 @@ def _run():
 
     path = os.path.join(base, script)
     sys.argv[0] = __file__ = path
-    with open(path) as fp:
+    with open(path, 'rU') as fp:
         source = fp.read() + "\n"
     exec(compile(source, path, 'exec'), globals(), globals())
