@@ -12,7 +12,7 @@ def _run():
 
     path = os.path.join(base, script)
     __file__ = path
-    with open(path) as fp:
+    with open(path, 'rU') as fp:
         source = fp.read()
     exec(compile(source, path, 'exec'), globals(), globals())
 
