@@ -1,6 +1,3 @@
-from pkg_resources import require
-require("macholib")
-
 import os
 import sys
 from macholib.util import has_filename_filter, in_system_path
