@@ -10,10 +10,15 @@ PyQt4.Qt to PyQt4.QtCore) are handled in C code and therefore cannot be
 detected by the python code in py2app).
 """
 
+import sys
+import glob
+import os
+import pkg_resources
+
 class Sip(object):
     def __init__(self):
         self.packages = None
-        self.warn = None
+        self.plugin_dir = None
 
     def config(self):
         if self.packages is not None:
@@ -44,8 +49,9 @@ class Sip(object):
             dyld_library_path.insert(0, qtdir)
             os.environ['DYLD_LIBRARY_PATH'] = ':'.join(dyld_library_path)
 
-        sipdir = cfg.default_sip_dir
+        sipdir = os.path.dirname(cfg.pyqt_mod_dir)
         self.packages = set()
+        self.plugin_dir = os.path.join(cfg.qt_dir, 'plugins')
 
         for fn in os.listdir(sipdir):
             fullpath = os.path.join(sipdir, fn)
@@ -55,9 +61,15 @@ class Sip(object):
                     # PyQt4 has a nested structure, also import
                     # subpackage to ensure everything get seen.
                     for sub in os.listdir(fullpath):
-                        self.packages.add('%s.%s'%(fn, sub))
-                
-        self.warn = cfg.qt_edition == 'free'
+                        if ".py" not in sub:
+                            self.packages.add('%s.%s'%(fn, sub.replace(".so","")))                            
+
+        # Causes a python3-related syntax error (metaclass keyword),
+        # and you probably don't need it:
+        #if "PyQt4.uic" in self.packages and sys.version_info.major != 3:
+        #    print("WARNING: PyQt uic module found.")
+        #    print("avoid python3 metaclass syntax errors by adding 'PyQt4.uic' to your excludes option.")
+
         return self.packages
 
     def check(self, cmd, mf):
@@ -66,6 +78,19 @@ class Sip(object):
         except ImportError:
             return dict()
 
+        if 'PyQt4.uic' in packages:
+            # PyQt4.uic contains subpackages with python 2 and python 3
+            # support. Exclude the variant that won't be ussed, this avoids
+            # compilation errors on Python 2 (because some of the Python 3
+            # code is not valid Python 2 code)
+            if sys.version_info[0] == 2:
+                ref = 'PyQt4.uic.port_v3'
+            else:
+                ref = 'PyQt4.uic.port_v2'
+
+            # Exclude...
+            mf.lazynodes[ref] = None
+
         for pkg in packages:
             m = mf.findNode(pkg)
             if m is not None and m.filename is not None:
@@ -78,14 +103,26 @@ class Sip(object):
         # naive inclusion of ALL sip packages
         # stupid C modules.. hate hate hate
         for pkg in packages:
-            mf.import_hook(pkg, m)
-        if self.warn:
-            print ''
-            print '== PyQt Free Edition GPL warning =='
-            print 'Your application is including PyQt Free Edition!'
-            print 'Please read the terms of the GPL license before'
-            print 'distributing this application!'
-            print ''
+            try:
+                mf.import_hook(pkg, m)
+            except ImportError as exc:
+                print("WARNING: ImportError in sip recipe ignored: %s"%(exc,))
+
+        if mf.findNode('PyQt4') is not None:
+            resources = [pkg_resources.resource_filename('py2app', 'recipes/qt.conf')]
+
+            for item in cmd.qt_plugins:
+                if '/' not in item:
+                    item = item + '/*'
+
+                if '*' in item:
+                    for path in glob.glob(os.path.join(self.plugin_dir, item)):
+                        resources.append((os.path.dirname('qt_plugins' + path[len(self.plugin_dir):]), [path]))
+                else:
+                    resources.append((os.path.dirname(os.path.join('qt_plugins', item)), os.path.join(self.plugin_dir, item)))
+
+            return dict(resources=resources)
+
         return dict()
 
 check = Sip().check
