@@ -1,15 +1,15 @@
-from pkg_resources import require
-require("modulegraph", "altgraph", "macholib")
+from __future__ import print_function
 
-import os, sys, imp, time
+import os, sys, imp, time, errno
 from modulegraph.find_modules import PY_SUFFIXES, C_SUFFIXES
 from modulegraph.util import *
 from modulegraph import zipio
-from altgraph.compat import *
 import macholib.util
 import warnings
+from distutils import log
 
 import pkg_resources
+import subprocess
 
 # Deprecated functionality
 def os_path_islink(path):
@@ -90,7 +90,7 @@ def find_converter(source):
         for ep in pkg_resources.iter_entry_points('py2app.converter'):
             function = ep.load()
             if not hasattr(function, "py2app_suffix"):
-                print "WARNING: %s does not have 'py2app_suffix' attribute"%(function)
+                print("WARNING: %s does not have 'py2app_suffix' attribute"%(function))
                 continue
             gConverterTab[function.py2app_suffix] = function
 
@@ -132,21 +132,33 @@ def copy_resource(source, destination, dry_run=0, symlink=0):
 
 
 
-def copy_file(source, destination, dry_run=0):
-    fp_in = zipio.open(source, 'rb')
-    fp_out = None
-    try:
+def copy_file(source, destination, preserve_mode=False, preserve_times=False, update=False, dry_run=0):
+    while True:
+        try:
+            _copy_file(source, destination, preserve_mode, preserve_times, update, dry_run)
+            return
+        except IOError as exc:
+            if exc.errno != errno.EAGAIN:
+                raise
+
+            log.info("copying file %s failed due to spurious EAGAIN, retrying in 2 seconds", source)
+            time.sleep(2)
+
+def _copy_file(source, destination, preserve_mode=False, preserve_times=False, update=False, dry_run=0):
+    log.info("copying file %s -> %s", source, destination)
+    with zipio.open(source, 'rb') as fp_in:
         if not dry_run:
-            fp_out = open(destination, 'wb')
-            fp_out.write(fp_in.read())
-
-    finally:
-        fp_in.close()
-        if fp_out is not None:
-            fp_out.close()
-
+            with open(destination, 'wb') as fp_out:
+                data = fp_in.read()
+                fp_out.write(data)
 
+            if preserve_mode:
+                # XXX: copy current mode
+                pass
 
+            if preserve_times:
+                # XXX: copy current times
+                pass
 
 
 def newer(source, target):
@@ -168,10 +180,10 @@ def find_version(fn):
     from compiler.ast import Module, Stmt, Assign, AssName, Const
     ast = compiler.parseFile(fn)
     if not isinstance(ast, Module):
-        raise ValueError, "expecting Module"
+        raise ValueError("expecting Module")
     statements = ast.getChildNodes()
     if not (len(statements) == 1 and isinstance(statements[0], Stmt)):
-        raise ValueError, "expecting one Stmt"
+        raise ValueError("expecting one Stmt")
     for node in statements[0].getChildNodes():
         if not isinstance(node, Assign):
             continue
@@ -187,7 +199,7 @@ def find_version(fn):
             continue
         return node.expr.value
     else:
-        raise ValueError, "Version not found"
+        raise ValueError("Version not found")
 
 def in_system_path(filename):
     """
@@ -205,7 +217,7 @@ else:
 def make_exec(path):
     mask = os.umask(0)
     os.umask(mask)
-    os.chmod(path, os.stat(path).st_mode | (0111 & ~mask))
+    os.chmod(path, os.stat(path).st_mode | (0o111 & ~mask))
 
 def makedirs(path):
     path = fsencoding(path)
@@ -275,7 +287,7 @@ def __load():
             continue
         ext = os.path.join(path, ext)
         if os.path.exists(ext):
-            #print "py2app extension module", __name__, "->", ext
+            #print("py2app extension module", __name__, "->", ext)
             mod = imp.load_dynamic(__name__, ext)
             #mod.frozen = 1
             break
@@ -304,27 +316,25 @@ def byte_compile(py_files, optimize=0, force=0,
         from distutils.util import execute, spawn
         script_name = mktemp(".py")
         if verbose:
-            print "writing byte-compilation script '%s'" % script_name
+            print("writing byte-compilation script '%s'" % script_name)
         if not dry_run:
-            script = open(script_name, "w")
-            script.write("""
+            with open(script_name, "w") as script:
+                script.write("""
 from py2app.util import byte_compile
 from modulegraph.modulegraph import *
 files = [
 """)
 
-            for f in py_files:
-                script.write(repr(f) + ",\n")
-            script.write("]\n")
-            script.write("""
+                for f in py_files:
+                    script.write(repr(f) + ",\n")
+                script.write("]\n")
+                script.write("""
 byte_compile(files, optimize=%r, force=%r,
              target_dir=%r,
              verbose=%r, dry_run=0,
              direct=1)
 """ % (optimize, force, target_dir, verbose))
 
-            script.close()
-
         # Ensure that py2app is on PYTHONPATH, this ensures that
         # py2app.util can be found even when we're running from
         # an .egg that was downloaded by setuptools
@@ -366,7 +376,7 @@ byte_compile(files, optimize=%r, force=%r,
 
             if force or newer(mod.filename, cfile):
                 if verbose:
-                    print "byte-compiling %s to %s" % (mod.filename, dfile)
+                    print("byte-compiling %s to %s" % (mod.filename, dfile))
                     
                 if not dry_run:
                     mkpath(os.path.dirname(cfile))
@@ -375,11 +385,9 @@ byte_compile(files, optimize=%r, force=%r,
                     if suffix in ('.py', '.pyw'):
                         fn = cfile + '.py'
 
-                        fp_in = zipio.open(mod.filename, 'rb')
-                        fp_out = open(fn, 'wb')
-                        fp_out.write(fp_in.read())
-                        fp_in.close()
-                        fp_out.close()
+                        with zipio.open(mod.filename, 'rb') as fp_in:
+                            with open(fn, 'wb') as fp_out:
+                                fp_out.write(fp_in.read())
 
                         compile(fn, cfile, dfile)
                         os.unlink(fn)
@@ -395,8 +403,8 @@ byte_compile(files, optimize=%r, force=%r,
                               ("Don't know how to handle %r" % mod.filename)
             else:
                 if verbose:
-                    print "skipping byte-compilation of %s to %s" % \
-                          (mod.filename, dfile)
+                    print("skipping byte-compilation of %s to %s" % 
+                          (mod.filename, dfile))
 
 SCMDIRS = ['CVS', '.svn']
 def skipscm(ofn):
@@ -494,7 +502,6 @@ def copy_tree(src, dst,
 
 
     from distutils.dir_util import mkpath
-    from distutils.file_util import copy_file
     from distutils.dep_util import newer
     from distutils.errors import DistutilsFileError
     from distutils import log
@@ -505,17 +512,18 @@ def copy_tree(src, dst,
     if condition is None:
         condition = skipscm
 
-    if not dry_run and not os.path.isdir(src):
-        raise DistutilsFileError, \
-              "cannot copy tree '%s': not a directory" % src
+    if not dry_run and not zipio.isdir(src):
+        raise DistutilsFileError(
+              "cannot copy tree '%s': not a directory" % src)
     try:
         names = zipio.listdir(src)
-    except os.error, (errno, errstr):
+    except os.error as exc:
+        (errno, errstr) = exc.args
         if dry_run:
             names = []
         else:
-            raise DistutilsFileError, \
-                  "error listing files in '%s': %s" % (src, errstr)
+            raise DistutilsFileError(
+                  "error listing files in '%s': %s" % (src, errstr))
 
     if not dry_run:
         mkpath(dst)
@@ -540,7 +548,10 @@ def copy_tree(src, dst,
                     os.symlink(link_dest, dst_name)
             outputs.append(dst_name)
 
-        elif os.path.isdir(src_name):
+        elif zipio.isdir(src_name) and not os.path.isfile(src_name):
+            # ^^^ this odd tests ensures that resource files that
+            # happen to be a zipfile won't get extracted.
+            # XXX: need API in zipio to clean up this code
             outputs.extend(
                 copy_tree(src_name, dst_name, preserve_mode,
                           preserve_times, preserve_symlinks, update,
@@ -570,17 +581,52 @@ def find_app(app):
             return dpath
     return None
 
-MOMC = '/Library/Application Support/Apple/Developer Tools/Plug-ins/XDCoreDataModel.xdplugin/Contents/Resources/momc'
-if not os.path.exists(MOMC):
-    MOMC = '/Developer/Library/Xcode/Plug-ins/XDCoreDataModel.xdplugin/Contents/Resources/momc'
-if not os.path.exists(MOMC):
-    MOMC = '/Developer/usr/bin/momc'
+def check_output(command_line):
+    p = subprocess.Popen(command_line,
+            stdout=subprocess.PIPE)
+    stdout, _ = p.communicate()
+    xit = p.wait()
+    if xit != 0:
+        raise subprocess.CalledProcessError(xit, command_line)
+
+    return stdout
+
+
+_tools = {}
+def _get_tool(toolname):
+    if toolname not in _tools:
+        if os.path.exists('/usr/bin/xcrun'):
+            try:
+                _tools[toolname] = check_output(['/usr/bin/xcrun', '-find', 'momc'])[:-1]
+            except subprocess.CalledProcessError:
+                raise IOError("Tool %r not found"%(toolname,))
+
+        else:
+            # Support for Xcode 3.x and earlier
+            if toolname == 'momc':
+                choices = [
+    	            '/Library/Application Support/Apple/Developer Tools/Plug-ins/XDCoreDataModel.xdplugin/Contents/Resources/momc',
+                    '/Developer/Library/Xcode/Plug-ins/XDCoreDataModel.xdplugin/Contents/Resources/momc',
+                    '/Developer/usr/bin/momc',
+                ]
+            elif toolname == 'mapc':
+                choices = [
+                    '/Developer/Library/Xcode/Plug-ins/XDMappingModel.xdplugin/Contents/Resources/mapc'
+                    '/Developer/usr/bin/mapc'
+                ]
+            else:
+                raise IOError("Tool %r not found"%(toolname,))
+
+            for fn in choices:
+                if os.path.exists(fn):
+                    _tools[toolname] = fn
+                    break 
+            else:
+                raise IOError("Tool %r not found"%(toolname,))
+
 
 def momc(src, dst):
-    os.spawnv(os.P_WAIT, MOMC, [MOMC, src, dst])
+    subprocess.check_call([_get_tool('momc'), src, dst])
 
-MAPC = '/Developer/Library/Xcode/Plug-ins/XDMappingModel.xdplugin/Contents/Resources/mapc'
-if not os.path.exists(MAPC):
-    MAPC = '/Developer/usr/bin/mapc'
 def mapc(src, dst):
-    os.spawnv(os.P_WAIT, MAPC, [MAPC, src, dst])
+    subprocess.check_call([_get_tool('mapc'), src, dst])
