@@ -13,20 +13,11 @@ import shutil
 import time
 import os
 import signal
+import platform
 import py2app
 
 DIR_NAME=os.path.dirname(os.path.abspath(__file__))
 
-if sys.version_info[0] == 2:
-    def B(value):
-        return value
-
-else:
-    def B(value):
-        return value.encode('latin1')
-
-
-
 
 class TestArgvEmulation (unittest.TestCase):
     py2app_args = []
@@ -74,6 +65,11 @@ class TestArgvEmulation (unittest.TestCase):
 
     def test_basic_start(self):
         self.maxDiff = None
+
+        path = os.path.join( self.app_dir, 'dist/argv.txt')
+        if os.path.exists(path):
+            os.unlink(path)
+
         path = os.path.join( self.app_dir, 'dist/BasicApp.app')
 
         p = subprocess.Popen(["/usr/bin/open",
@@ -98,6 +94,11 @@ class TestArgvEmulation (unittest.TestCase):
 
     def test_start_with_args(self):
         self.maxDiff = None
+
+        path = os.path.join( self.app_dir, 'dist/argv.txt')
+        if os.path.exists(path):
+            os.unlink(path)
+
         path = os.path.join( self.app_dir, 'dist/BasicApp.app')
 
         p = subprocess.Popen(["/usr/bin/open",
@@ -106,6 +107,37 @@ class TestArgvEmulation (unittest.TestCase):
 
         self.assertEqual(exit, 0)
 
+        path = os.path.join( self.app_dir, 'dist/argv.txt')
+        for x in range(90):     # Argv emulation can take up-to 60 seconds
+            time.sleep(1)
+            if os.path.exists(path):
+                break
+
+        self.assertTrue(os.path.isfile(path))
+
+        fp = open(path, 'r')
+        data = fp.read().strip()
+        fp.close()
+
+        self.assertEqual(data.strip(), repr([os.path.join(self.app_dir, 'dist/BasicApp.app/Contents/Resources/main.py'), self.open_argument]))
+
+    @unittest.skipIf(platform.mac_ver()[0] < '10.6.', "Test cannot work on OSX 10.5 or earlier")
+    def test_start_with_two_args(self):
+        if not self.open_argument.startswith('/'):
+            unittest.skip("Only relevant for base class")
+
+        path = os.path.join( self.app_dir, 'dist/argv.txt')
+        if os.path.exists(path):
+            os.unlink(path)
+
+        self.maxDiff = None
+        path = os.path.join( self.app_dir, 'dist/BasicApp.app')
+
+        p = subprocess.Popen(["/usr/bin/open",
+                '-a', path, "--args", "one", "two", "three"])
+        exit = p.wait()
+        self.assertEqual(exit, 0)
+
         path = os.path.join( self.app_dir, 'dist/argv.txt')
         for x in range(70):     # Argv emulation can take up-to 60 seconds
             time.sleep(1)
@@ -118,9 +150,9 @@ class TestArgvEmulation (unittest.TestCase):
         data = fp.read().strip()
         fp.close()
 
-        self.assertEqual(data.strip(), repr([os.path.join(self.app_dir, 'dist/BasicApp.app/Contents/Resources/main.py'), self.open_argument]))
+        self.assertEqual(data.strip(), repr([os.path.join(self.app_dir, 'dist/BasicApp.app/Contents/Resources/main.py'), "one", "two", "three"]))
 
-class TestArgvEmulationWithUrL (TestArgvEmulation):
+class TestArgvEmulationWithURL (TestArgvEmulation):
     py2app_args = []
     setup_file = "setup-with-urlscheme.py"
     open_argument = 'myurl:mycommand'
